==> pydantic_schemaorg-0.0.2.tar.gz: pydantic_schemaorg-0.0.2/pydantic_schemaorg/DataDownload.py <==
from pydantic import Field, AnyUrl
from typing import Any, Union, List, Optional
from pydantic_schemaorg.MediaObject import MediaObject


class DataDownload(MediaObject):
    """A dataset in downloadable form.

    See https://schema.org/DataDownload.

    """

    measurementTechnique: Optional[Union[List[Union[AnyUrl, str]], Union[AnyUrl, str]]] = Field(
        None,
        description="A technique or technology used in a [[Dataset]] (or [[DataDownload]], [[DataCatalog]]),"
     "corresponding to the method used for measuring the corresponding variable(s) (described"
     "using [[variableMeasured]]). This is oriented towards scientific and scholarly dataset"
     "publication but may have broader applicability; it is not intended as a full representation"
     "of measurement, but rather as a high level summary for dataset discovery. For example,"
     "if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]]"
     "could be: \"mass spectrometry\" or \"nmr spectroscopy\" or \"colorimetry\" or \"immunofluorescence\"."
     "If the [[variableMeasured]] is \"depression rating\", the [[measurementTechnique]]"
     "could be \"Zung Scale\" or \"HAM-D\" or \"Beck Depression Inventory\". If there are"
     "several [[variableMeasured]] properties recorded for some given data object, use"
     "a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]].",
    )
    locals().update({"@type": Field("DataDownload", const=True)})


DataDownload.update_forward_refs()

==> pydantic_schemaorg-0.1.0.tar.gz: pydantic_schemaorg-0.1.0/pydantic_schemaorg/DataDownload.py <==
from pydantic import AnyUrl, Field
from typing import List, Optional, Union
from pydantic_schemaorg.MediaObject import MediaObject


class DataDownload(MediaObject):
    """A dataset in downloadable form.

    See https://schema.org/DataDownload.

    """
    type_: str = Field("DataDownload", const=True, alias='@type')
    measurementTechnique: Optional[Union[List[Union[AnyUrl, str]], Union[AnyUrl, str]]] = Field(
        None,
        description="A technique or technology used in a [[Dataset]] (or [[DataDownload]], [[DataCatalog]]),"
     "corresponding to the method used for measuring the corresponding variable(s) (described"
     "using [[variableMeasured]]). This is oriented towards scientific and scholarly dataset"
     "publication but may have broader applicability; it is not intended as a full representation"
     "of measurement, but rather as a high level summary for dataset discovery. For example,"
     "if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]]"
     "could be: \"mass spectrometry\" or \"nmr spectroscopy\" or \"colorimetry\" or \"immunofluorescence\"."
     "If the [[variableMeasured]] is \"depression rating\", the [[measurementTechnique]]"
     "could be \"Zung Scale\" or \"HAM-D\" or \"Beck Depression Inventory\". If there are"
     "several [[variableMeasured]] properties recorded for some given data object, use"
     "a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]].",
    )
    

DataDownload.update_forward_refs()
